@@ -1,67 +1,69 @@
 var languageNames = {
 "en-US": "Inglés (EXA)",
+"sq": "Albanian",
 "am": "Amáricu",
 "ar": "Árabe",
 "ast": "Asturianu",
-"bg": "Búlgaru",
 "bn": "Bengalín",
 "bn-IN": "Bengalín (India)",
-"bo": "Tibetanu",
 "bs": "Bosniu",
+"bg": "Búlgaru",
 "ca": "Catalán",
-"ca-valencia": "Catalán (valencianu)",
+"ca-valencia": "Catalan (Valencia)",
+"zh-CN": "Chinu (simplificáu)",
+"zh-TW": "Chinu (tradicional)",
+"hr": "Croatian",
 "cs": "Checu",
 "da": "Danés",
-"de": "Alemán",
+"nl": "Dutch",
 "dz": "Butanés",
-"el": "Griegu",
 "en-GB": "Inglés (RX)",
 "en-ZA": "Inglés (Sudáf.)",
 "eo": "Esperantu",
-"es": "Spanish",
-"et": "Estonian",
+"et": "Estoniu",
 "eu": "Vascu",
 "fi": "Finnish",
-"fr": "French",
+"fr": "Francés",
 "gl": "Gallegu",
+"ka": "Xeorxanu",
+"de": "Alemán",
+"el": "Griegu",
 "gu": "Gujarati",
 "he": "Hebréu",
 "hi": "Hindi",
-"hr": "Croatian",
 "hu": "Hungarian",
-"id": "Indonesian",
+"id": "Indonesiu",
 "is": "Icelandic",
-"it": "Italian",
-"ja": "Japanese",
-"ka": "Georgian",
+"it": "Italianu",
+"ja": "Xaponés",
 "km": "Ḥemer",
 "ko": "Korean",
 "lo": "Lao",
-"lt": "Lithuanian",
 "lv": "Latvian",
+"lt": "Lithuanian",
 "mk": "Macedonian",
-"nb": "Norwegian Bokmål",
 "ne": "Nepali",
-"nl": "Dutch",
 "nn": "Norwegian Nynorsk",
+"nb": "Norwegian Bokmål",
 "om": "Oromo",
 "pl": "Polish",
 "pt": "Portuguese",
-"pt-BR": "Portugués (brasilanu)",
+"pt-BR": "Portuguese (Brazil)",
 "ro": "Romanian",
 "ru": "Russian",
-"si": "Sinhala",
 "sid": "Sidama",
+"si": "Sinhala",
 "sk": "Slovak",
 "sl": "Slovenian",
-"sq": "Albanian",
+"dsb": "Sorbian (Lower)",
+"hsb": "Sorbian (Upper)",
+"es": "Castellanu",
 "sv": "Swedish",
-"ta": "Tamil",
 "tg": "Tajik",
+"ta": "Tamil",
+"bo": "Tibetanu",
 "tr": "Turkish",
 "ug": "Uyghur",
 "uk": "Ucraín",
 "vi": "Vietnamese",
-"zh-CN": "Chinu (simplificáu)",
-"zh-TW": "Chinu (tradicional)",
 };
